#include "Menu.hpp"

#include <Graphics/Font.hpp>

Menu::Menu() : current_choice(0), current_position(0) {
}

Menu::~Menu() {
}

void Menu::draw() {
	glClearColor(0.0f, 0.3f, 0.2f, 0.0f);
	glClear(GL_COLOR_BUFFER_BIT);
	Graphics::FontRef font = Graphics::get_font("gentium.txf");
	assert(font.ref);
	for (unsigned int c = 0; c < choices.size(); ++c) {
		if (c == current_choice) {
			glColor3f(1.0f, 0.3f, 1.0f);
		} else {
			glColor3f(0.7f, 0.7f, 0.7f);
		}
		font->draw_center(choices[c].first, make_vector(0.0f,-0.1f * (c - current_position)), 0.1f);
	}
	glColor3f(0.7f, 0.7f, 0.7f);
	font->draw_center("nest Demos", make_vector(0.0f, 0.8f), 0.2f);
	glColor3f(0.5f, 0.5f, 0.5f);
	font->draw("UP/DOWN to select, ENTER to invoke, ESC to quit", make_vector(-Graphics::aspectf(),-1.0f), 0.07f);
}

void Menu::update(float elapsed_time) {
	float desired_position = current_choice;
	//we'll move the current position toward the desired position at 5 units/sec
	float amt = 5.0f * elapsed_time;
	if (current_position - amt > desired_position) {
		current_position -= amt;
	} else if (current_position + amt < desired_position) {
		current_position += amt;
	} else {
		current_position = desired_position;
	}
}

void Menu::handle_event(SDL_Event const &event) {
	if (event.type == SDL_KEYDOWN) {
		if (event.key.keysym.sym == SDLK_UP) {
			if (current_choice - 1 < choices.size()) {
				current_choice -= 1;
			}
		} else if (event.key.keysym.sym == SDLK_DOWN) {
			if (current_choice + 1 < choices.size()) {
				current_choice += 1;
			}
		} else if (event.key.keysym.sym == SDLK_RETURN) {
			if (current_choice < choices.size()) {
				start_screen(choices[current_choice].second);
			}
		} else if (event.key.keysym.sym == SDLK_ESCAPE) {
			quit_screen(this);
		}
	}
}


