#include <Basis/Screen.hpp>
#include "Menu.hpp"
#include "Timing.hpp"
#include "Textures.hpp"
#include "Mouse.hpp"

#include <Graphics/Graphics.hpp>

#include <SDL.h>
#include <SDL_opengl.h>

#include <Basis/Log.hpp>

int main(int argc, char **argv) {

	if (SDL_Init(SDL_INIT_TIMER) != 0) {
		LOG_ERROR("Could not initialize sdl: " << SDL_GetError());
		return 1;
	}

	//ask for a specific screen size:
	Graphics::screen.x = 800;
	Graphics::screen.y = 600;
	Graphics::fullscreen = false;

	if (!Graphics::init()) {
		LOG_ERROR("Could not initialize graphics, not continuing.");
		exit(1);
	}

	//Some quick basic GL state:
	glMatrixMode(GL_PROJECTION);
	glLoadIdentity();
	glScalef(1.0f / Graphics::aspectf(), 1.0f, 1.0f);
	glMatrixMode(GL_MODELVIEW);
	glLoadIdentity();

	glEnable(GL_BLEND);
	glBlendFunc(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
	glEnable(GL_LINE_SMOOTH);

	//we'll draw our own cursor, thank you.
	SDL_ShowCursor(SDL_DISABLE);
	//if (argc > 2) {
	//	SDL_WM_GrabInput(SDL_GRAB_ON);
	//}
	
	//Don't need unicode translation for this just yet.
	//SDL_EnableUNICODE(1);

	{
		Menu m;
		Timing timing;
		Textures textures;
		Mouse mouse;
		m.choices.push_back(std::make_pair("Timing", &timing));
		m.choices.push_back(std::make_pair("Texture Loading", &textures));
		m.choices.push_back(std::make_pair("Mouse Input", &mouse));
		start_screen(&m);
	}

	Graphics::deinit();

	SDL_Quit();

	return 0;
}
